@@ -18,17 +18,19 @@
 #' calls Kmisc::readlines if available and base::readLines otherwise 
 read_lines_wrapper <- function( file ){
 	
-	size <- file.info(file)$size
-	size_MB <- size / 1e6
+	sz <- base::file.info(file)$size
+	size_MB <- sz / 1e6
 	
-	if( requireNamespace("Kmisc", quietly = TRUE)){
+	if( requireNamespace("data.table", quietly = TRUE)){
 		
-		allLines <- Kmisc::readlines(file)
+		allLines <- data.table::fread(file, sep=NULL,colClasses = "character", strip.white=F,
+		                              header=F,fill=T,data.table=F)[,1]
+
 		
 	} else {
 		
 		if( size_MB > 100){
-			warning("Consider installing package Kmisc to speed up file reading")
+			warning("Consider installing package data.table to speed up file reading")
 		}
 		
 		allLines <- readLines(file)
@@ -36,4 +38,4 @@ read_lines_wrapper <- function( file ){
 	}
 	
 	return (allLines)
-}
\ No newline at end of file
+}
